Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/srunx/cli/main.py | (no class) | 249 | 87 | 2 | 65%
src/srunx/cli/workflow.py | (no class) | 89 | 3 | 2 | 97%
src/srunx/client.py | Slurm | 107 | 17 | 0 | 84%
src/srunx/client.py | (no class) | 27 | 0 | 0 | 100%
src/srunx/logging.py | (no class) | 26 | 17 | 0 | 35%
src/srunx/models.py | JobStatus | 0 | 0 | 0 | 100%
src/srunx/models.py | JobResource | 0 | 0 | 0 | 100%
src/srunx/models.py | JobEnvironment | 5 | 0 | 0 | 100%
src/srunx/models.py | BaseJob | 23 | 23 | 0 | 0%
src/srunx/models.py | Job | 0 | 0 | 0 | 100%
src/srunx/models.py | ShellJob | 0 | 0 | 0 | 100%
src/srunx/models.py | WorkflowTask | 0 | 0 | 0 | 100%
src/srunx/models.py | Workflow | 6 | 0 | 0 | 100%
src/srunx/models.py | (no class) | 79 | 1 | 0 | 99%
src/srunx/utils.py | (no class) | 25 | 20 | 0 | 20%
src/srunx/workflows/runner.py | WorkflowRunner | 56 | 1 | 0 | 98%
src/srunx/workflows/runner.py | (no class) | 19 | 0 | 0 | 100%
src/srunx/workflows/tasks.py | (no class) | 30 | 0 | 0 | 100%
Total |  | 741 | 169 | 4 | 77%

No items found using the specified filter.